cmd

package
v1.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 1, 2022 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package cmd contains the handler to configure and execute the subcommands and flags.

Example
package main

import (
	"os"

	"github.com/mauroalderete/gcode-cli/cmd"
)

func main() {
	// Makes a root command instance with version 1.0.0
	rootCmd := cmd.NewRootCommand("1.0.0")

	// Runs root command with the terminator function to handle exit process
	cmd.Execute(rootCmd, os.Exit)
}

Index

Examples

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute(cmd *cobra.Command, exit teminator)

Execute executes the root command passed by the parameter

func NewRootCommand

func NewRootCommand(version string) *cobra.Command

NewRootCommand make a root command instance

Recives a version number

Types

This section is empty.

Directories

Path Synopsis
Package describe is the subcommand to show the metadata from gcode file.
Package describe is the subcommand to show the metadata from gcode file.
Package skew contains the subcommand to apply skew correction
Package skew contains the subcommand to apply skew correction
xy
Package skew contains the subcommand to apply skew correction
Package skew contains the subcommand to apply skew correction
Package version is the subcommand to show the version number of gcode-cli.
Package version is the subcommand to show the version number of gcode-cli.

Jump to