Documentation
¶
Overview ¶
Package cmd contains the handler to configure and execute the subcommands and flags.
Example ¶
package main
import (
"os"
"github.com/mauroalderete/gcode-cli/cmd"
)
func main() {
// Makes a root command instance with version 1.0.0
rootCmd := cmd.NewRootCommand("1.0.0")
// Runs root command with the terminator function to handle exit process
cmd.Execute(rootCmd, os.Exit)
}
Output:
Index ¶
Examples ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
This section is empty.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package describe is the subcommand to show the metadata from gcode file.
|
Package describe is the subcommand to show the metadata from gcode file. |
|
Package skew contains the subcommand to apply skew correction
|
Package skew contains the subcommand to apply skew correction |
|
xy
Package skew contains the subcommand to apply skew correction
|
Package skew contains the subcommand to apply skew correction |
|
Package version is the subcommand to show the version number of gcode-cli.
|
Package version is the subcommand to show the version number of gcode-cli. |
Click to show internal directories.
Click to hide internal directories.